<!--
SPDX-FileCopyrightText: 2026 Helge Eichhorn <git@helgeeichhorn.de>

SPDX-License-Identifier: MPL-2.0
-->

# lox-bodies

Celestial body definitions and physical constants for the
[Lox](https://github.com/lox-space/lox) ecosystem.

Part of [Lox – Oxidized Astrodynamics](https://github.com/lox-space/lox).
